@@ -33,10 +33,11 @@
 #  define GAMMARAY_CLIENT_DEPRECATED_NO_EXPORT GAMMARAY_CLIENT_NO_EXPORT GAMMARAY_CLIENT_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef GAMMARAY_CLIENT_NO_DEPRECATED
 #    define GAMMARAY_CLIENT_NO_DEPRECATED
 #  endif
 #endif
 
-#endif
+#endif /* GAMMARAY_CLIENT_EXPORT_H */
